@@ -3,7 +3,9 @@ import copy
 from deepdiff import DeepDiff
 from nested_lookup import nested_delete
 
-from response_differ import play, get_grouped_exception
+#from response_differ import play, get_grouped_exception
+from . import play
+from .exceptions import get_grouped_exception
 
 
 def check_status_code(replayed):
