@@ -12,11 +12,11 @@ def bold(message):
 
 @click.group(context_settings={"help_option_names": ["-h", "--help"]})
 @click.version_option()
-def resp_diff():
+def differ():
     """Command line tool for testing your web application"""
 
 
-@resp_diff.command()
+@differ.command()
 @click.argument("cassette_path", type=click.Path(exists=True))
 @click.option("--uri", help="A regexp that filters interactions by their request URI.", required=False, type=str)
 @click.option("--diff", '-d',  help="Comparing new response with the old", required=False, type=bool)
@@ -37,5 +37,7 @@ def run(cassette_path, status=None, uri=None, diff=False, config=None):
         exception_cls = get_grouped_exception(*Replayed.errors)
         raise exception_cls(Replayed.errors)
     if diff:
-        Replayed.config = reed_conf(config)
+        with open(config) as fd2:
+            conf = yaml.load(fd2, Loader=yaml.SafeLoader)
+        Replayed.config = reed_conf(conf)
         check_diff_responses()
